ziggy.GraphReduce.hadoop_config

Package ziggy :: Package GraphReduce :: Module hadoop_config |
[hide private]
[frames] | no frames]

# Source Code for Module ziggy.GraphReduce.hadoop_config

     1  '''
     2  Created on May 17, 2010
     3  Generic configuration parameters for Hadoop-based python modules
     4  @author: dwmclary
     5  '''
     6
     7
     8  hadoop_home = "/usr/local/hadoop/" # The root directory of the hadoop installation
     9  hadoop = hadoop_home + "bin/hadoop" #/the location of the hadoop executable
    10  hadoop_streaming = hadoop_home + "contrib/streaming/hadoop-0.20.2-streaming.jar" #the location of that hadoop streaming jar
    11  num_map_tasks=20 #the number of map tasks currently configured
    12  GraphReduce_location = "/home/staff/dwmclary/workspace/GraphReduce/src/GraphReduce/"
    13